
From: Domen Puncer <domen@coderock.org>

Remove some of the unnecessary differences between arch/i386 and
arch/x86_64.  This patch fixes more whitespace issues, some miscellaneous
typos, a wrong URL and a factually incorrect statement about the current
boot sector code.

Signed-off-by: Domen Puncer <domen@coderock.org>
Signed-off-by: Andrew Morton <akpm@osdl.org>
---

 arch/i386/boot/Makefile            |    4 ++--
 arch/i386/boot/compressed/misc.c   |    1 -
 arch/i386/boot/edd.S               |    2 +-
 arch/i386/boot/setup.S             |    6 +++---
 arch/i386/boot/tools/build.c       |    5 ++---
 arch/x86_64/boot/compressed/head.S |    4 +---
 arch/x86_64/boot/compressed/misc.c |    2 +-
 arch/x86_64/boot/install.sh        |    2 +-
 arch/x86_64/boot/setup.S           |    8 ++++----
 arch/x86_64/boot/tools/build.c     |    5 ++---
 10 files changed, 17 insertions(+), 22 deletions(-)

diff -puN arch/i386/boot/compressed/misc.c~x86_64-coding-style-and-whitespace-fixups arch/i386/boot/compressed/misc.c
--- 25/arch/i386/boot/compressed/misc.c~x86_64-coding-style-and-whitespace-fixups	2005-04-26 01:25:13.005089808 -0700
+++ 25-akpm/arch/i386/boot/compressed/misc.c	2005-04-26 01:25:13.021087376 -0700
@@ -354,7 +354,6 @@ static void close_output_buffer_if_we_ru
 	}
 }
 
-
 asmlinkage int decompress_kernel(struct moveparams *mv, void *rmode)
 {
 	real_mode = rmode;
diff -puN arch/i386/boot/edd.S~x86_64-coding-style-and-whitespace-fixups arch/i386/boot/edd.S
--- 25/arch/i386/boot/edd.S~x86_64-coding-style-and-whitespace-fixups	2005-04-26 01:25:13.006089656 -0700
+++ 25-akpm/arch/i386/boot/edd.S	2005-04-26 01:25:13.021087376 -0700
@@ -6,7 +6,7 @@
  *   projects 1572D, 1484D, 1386D, 1226DT
  * disk signature read by Matt Domsch <Matt_Domsch@dell.com>
  *	and Andrew Wilks <Andrew_Wilks@dell.com> September 2003, June 2004
- * legacy CHS retreival by Patrick J. LoPresti <patl@users.sourceforge.net>
+ * legacy CHS retrieval by Patrick J. LoPresti <patl@users.sourceforge.net>
  *      March 2004
  * Command line option parsing, Matt Domsch, November 2004
  */
diff -puN arch/i386/boot/Makefile~x86_64-coding-style-and-whitespace-fixups arch/i386/boot/Makefile
--- 25/arch/i386/boot/Makefile~x86_64-coding-style-and-whitespace-fixups	2005-04-26 01:25:13.007089504 -0700
+++ 25-akpm/arch/i386/boot/Makefile	2005-04-26 01:25:13.022087224 -0700
@@ -25,8 +25,8 @@ SVGA_MODE := -DSVGA_MODE=NORMAL_VGA
 
 #RAMDISK := -DRAMDISK=512
 
-targets		:= vmlinux.bin bootsect bootsect.o setup setup.o \
-		   zImage bzImage
+targets		:= vmlinux.bin bootsect bootsect.o \
+		   setup setup.o zImage bzImage
 subdir- 	:= compressed
 
 hostprogs-y	:= tools/build
diff -puN arch/i386/boot/setup.S~x86_64-coding-style-and-whitespace-fixups arch/i386/boot/setup.S
--- 25/arch/i386/boot/setup.S~x86_64-coding-style-and-whitespace-fixups	2005-04-26 01:25:13.009089200 -0700
+++ 25-akpm/arch/i386/boot/setup.S	2005-04-26 01:25:13.023087072 -0700
@@ -33,7 +33,7 @@
  * Transcribed from Intel (as86) -> AT&T (gas) by Chris Noe, May 1999.
  * <stiker@northlink.com>
  *
- * Fix to work around buggy BIOSes which dont use carry bit correctly
+ * Fix to work around buggy BIOSes which don't use carry bit correctly
  * and/or report extended memory in CX/DX for e801h memory size detection 
  * call.  As a result the kernel got wrong figures.  The int15/e801h docs
  * from Ralf Brown interrupt list seem to indicate AX/BX should be used
@@ -357,7 +357,7 @@ bail820:
 
 meme801:
 	stc					# fix to work around buggy
-	xorw	%cx,%cx				# BIOSes which dont clear/set
+	xorw	%cx,%cx				# BIOSes which don't clear/set
 	xorw	%dx,%dx				# carry on pass/error of
 						# e801h memory size call
 						# or merely pass cx,dx though
@@ -847,7 +847,7 @@ flush_instr:
 #
 #	but we yet haven't reloaded the CS register, so the default size 
 #	of the target offset still is 16 bit.
-#       However, using an operand prefix (0x66), the CPU will properly
+#	However, using an operand prefix (0x66), the CPU will properly
 #	take our 48 bit far pointer. (INTeL 80386 Programmer's Reference
 #	Manual, Mixing 16-bit and 32-bit code, page 16-6)
 
diff -puN arch/i386/boot/tools/build.c~x86_64-coding-style-and-whitespace-fixups arch/i386/boot/tools/build.c
--- 25/arch/i386/boot/tools/build.c~x86_64-coding-style-and-whitespace-fixups	2005-04-26 01:25:13.010089048 -0700
+++ 25-akpm/arch/i386/boot/tools/build.c	2005-04-26 01:25:13.023087072 -0700
@@ -1,6 +1,4 @@
 /*
- *  $Id: build.c,v 1.5 1997/05/19 12:29:58 mj Exp $
- *
  *  Copyright (C) 1991, 1992  Linus Torvalds
  *  Copyright (C) 1997 Martin Mares
  */
@@ -8,7 +6,8 @@
 /*
  * This file builds a disk-image from three different files:
  *
- * - bootsect: exactly 512 bytes of 8086 machine code, loads the rest
+ * - bootsect: compatibility mbr which prints an error message if
+ *             someone tries to boot the kernel directly.
  * - setup: 8086 machine code, sets up system parm
  * - system: 80386 code for actual system
  *
diff -puN arch/x86_64/boot/compressed/head.S~x86_64-coding-style-and-whitespace-fixups arch/x86_64/boot/compressed/head.S
--- 25/arch/x86_64/boot/compressed/head.S~x86_64-coding-style-and-whitespace-fixups	2005-04-26 01:25:13.011088896 -0700
+++ 25-akpm/arch/x86_64/boot/compressed/head.S	2005-04-26 01:25:13.024086920 -0700
@@ -2,8 +2,6 @@
  *  linux/boot/head.S
  *
  *  Copyright (C) 1991, 1992, 1993  Linus Torvalds
- *
- *  $Id: head.S,v 1.3 2001/04/20 00:59:28 ak Exp $	 		
  */
 
 /*
@@ -21,7 +19,7 @@
  */
 
 /*
- * High loaded stuff by Hans Lermen & Werner Almesberger, Feb. 1996	
+ * High loaded stuff by Hans Lermen & Werner Almesberger, Feb. 1996
  */
 .code32
 .text
diff -puN arch/x86_64/boot/compressed/misc.c~x86_64-coding-style-and-whitespace-fixups arch/x86_64/boot/compressed/misc.c
--- 25/arch/x86_64/boot/compressed/misc.c~x86_64-coding-style-and-whitespace-fixups	2005-04-26 01:25:13.012088744 -0700
+++ 25-akpm/arch/x86_64/boot/compressed/misc.c	2005-04-26 01:25:13.024086920 -0700
@@ -97,7 +97,7 @@ void* memset(void* s, int c, unsigned n)
 void* memcpy(void* dest, const void* src, unsigned n);
 
 static void putstr(const char *);
-  
+
 extern int end;
 static long free_mem_ptr = (long)&end;
 static long free_mem_end_ptr;
diff -puN arch/x86_64/boot/install.sh~x86_64-coding-style-and-whitespace-fixups arch/x86_64/boot/install.sh
--- 25/arch/x86_64/boot/install.sh~x86_64-coding-style-and-whitespace-fixups	2005-04-26 01:25:13.014088440 -0700
+++ 25-akpm/arch/x86_64/boot/install.sh	2005-04-26 01:25:13.025086768 -0700
@@ -1,6 +1,6 @@
 #!/bin/sh
 #
-# arch/i386/boot/install.sh
+# arch/x86_64/boot/install.sh
 #
 # This file is subject to the terms and conditions of the GNU General Public
 # License.  See the file "COPYING" in the main directory of this archive
diff -puN arch/x86_64/boot/setup.S~x86_64-coding-style-and-whitespace-fixups arch/x86_64/boot/setup.S
--- 25/arch/x86_64/boot/setup.S~x86_64-coding-style-and-whitespace-fixups	2005-04-26 01:25:13.015088288 -0700
+++ 25-akpm/arch/x86_64/boot/setup.S	2005-04-26 01:25:13.026086616 -0700
@@ -33,7 +33,7 @@
  * Transcribed from Intel (as86) -> AT&T (gas) by Chris Noe, May 1999.
  * <stiker@northlink.com>
  *
- * Fix to work around buggy BIOSes which dont use carry bit correctly
+ * Fix to work around buggy BIOSes which don't use carry bit correctly
  * and/or report extended memory in CX/DX for e801h memory size detection 
  * call.  As a result the kernel got wrong figures.  The int15/e801h docs
  * from Ralf Brown interrupt list seem to indicate AX/BX should be used
@@ -383,7 +383,7 @@ sse_ok:
 # a whole bunch of different types, and allows memory holes and
 # everything.  We scan through this memory map and build a list
 # of the first 32 memory areas, which we return at [E820MAP].
-# This is documented at http://www.teleport.com/~acpi/acpihtml/topic245.htm
+# This is documented at http://www.acpi.info/, in the ACPI 2.0 specification.
 
 #define SMAP  0x534d4150
 
@@ -436,7 +436,7 @@ bail820:
 
 meme801:
 	stc					# fix to work around buggy
-	xorw	%cx,%cx				# BIOSes which dont clear/set
+	xorw	%cx,%cx				# BIOSes which don't clear/set
 	xorw	%dx,%dx				# carry on pass/error of
 						# e801h memory size call
 						# or merely pass cx,dx though
@@ -733,7 +733,7 @@ flush_instr:
 #
 #	but we yet haven't reloaded the CS register, so the default size 
 #	of the target offset still is 16 bit.
-#       However, using an operant prefix (0x66), the CPU will properly
+#	However, using an operand prefix (0x66), the CPU will properly
 #	take our 48 bit far pointer. (INTeL 80386 Programmer's Reference
 #	Manual, Mixing 16-bit and 32-bit code, page 16-6)
 
diff -puN arch/x86_64/boot/tools/build.c~x86_64-coding-style-and-whitespace-fixups arch/x86_64/boot/tools/build.c
--- 25/arch/x86_64/boot/tools/build.c~x86_64-coding-style-and-whitespace-fixups	2005-04-26 01:25:13.017087984 -0700
+++ 25-akpm/arch/x86_64/boot/tools/build.c	2005-04-26 01:25:13.026086616 -0700
@@ -1,6 +1,4 @@
 /*
- *  $Id: build.c,v 1.3 2001/06/26 15:14:50 pavel Exp $
- *
  *  Copyright (C) 1991, 1992  Linus Torvalds
  *  Copyright (C) 1997 Martin Mares
  */
@@ -8,7 +6,8 @@
 /*
  * This file builds a disk-image from three different files:
  *
- * - bootsect: exactly 512 bytes of 8086 machine code, loads the rest
+ * - bootsect: compatibility mbr which prints an error message if
+ *             someone tries to boot the kernel directly.
  * - setup: 8086 machine code, sets up system parm
  * - system: 80386 code for actual system
  *
_
